import store from '../../store'
import create from '../../utils/create'
import getDistance from '../../utils/distance'
import fetch from '../../utils/http'
import {
  get as getApi
} from '../../config/api'

const app = getApp()

create(store, {
  onShow() {
    wx.setNavigationBarTitle({
      title: '收藏的楼盘'
    })
  },
  onLoad() {
    const userInfo = app.globalData.UserInfo
    let _self = this
    wx.getSystemInfo({
      success(res) {
        _self.setData({
          WindowHeight: res.windowHeight
        })
      }
    })
    this.GetList()
  },
  data: {
    list: [],
    PostData: {
      pageNum: 1,
      pageSize: 10
    },
    Total: 1,
    IsLock: false,
    IsNull: false,
    WindowHeight: 0
  },
  GetList() {
    if (!this.data.IsLock && this.data.Total > this.data.list.length) {
      this.setData({
        IsLock: true
      })
      let {
        latitude,
        longitude
      } = this.store.data.location

      let userInfo = app.globalData.UserInfo

      fetch({
        ...getApi('user.building', {
          openid: userInfo.openid
        }),
        query: {
          ...this.data.PostData
        },
      }).then(({
        data
      }) => {
        const list = (data.records || []).map((it) => {
          const [lat = 0, lon = 0] = it.coordinate.split(',')
          return {
            ...it,
            distance: parseInt(getDistance(latitude, longitude, lat - 0, lon - 0))
          }
        })
        let aArr = this.data.list || []
        list.map((item) => {
          aArr.push(item)
        })
        this.setData({
          list: aArr,
          Total: data.total,
          PostData: {
            ...this.data.PostData,
            pageNum: this.data.PostData.pageNum + 1
          }
        })
        this.setData({
          IsNull: !this.data.list.length
        })
        setTimeout(() => {
          this.setData({
            IsLock: false
          })
        }, 300)
      }).catch((err) => {
        wx.showToast({
          title: '获取列表失败',
          icon: 'none',
        })
        setTimeout(() => {
          this.setData({
            IsLock: false
          })
        }, 300)
      })
    }
  },
  DeleteItem(e) { // 确认删除逻辑
    const buildingId = e.target.dataset.index
    const userInfo = app.globalData.UserInfo
    const _self = this

    wx.showModal({
      title: '确认',
      content: '确认要删除当前记录?',
      success(res) {
        if (res.confirm) {

          fetch({
            ...getApi('user.delBuilding', {
              openid: userInfo.openid
            }),
            query: {
              buildingId
            },
          }).then(() => {
            const list = _self.data.list.filter(x => x.buildingId !== buildingId)

            _self.setData({
              list
            })
          }).catch((err) => {
            wx.showToast({
              title: '删除失败',
              icon: 'none',
            })
          })

        } else if (res.cancel) {
          console.log('用户点击取消')
        }
      }
    })
  }
})